pub fn style_transform3d(style: &Option<Style>) -> Option<Transform3d>Expand description
Convenience for the wire params carried by a style, if any.
pub fn style_transform3d(style: &Option<Style>) -> Option<Transform3d>Convenience for the wire params carried by a style, if any.